"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FirebaseApp = void 0;
const FirebaseFunctionsCaller_1 = require("./FirebaseFunctionsCaller");
const FirebaseAuthenticator_1 = require("./FirebaseAuthenticator");
const FirebaseFirestore_1 = require("./FirebaseFirestore");
const firestore_1 = require("../firestore");
const functions_1 = require("firebase/functions");
const auth_1 = require("firebase/auth");
const firestore_2 = require("firebase/firestore");
class FirebaseApp {
    options;
    functionsEmulatorConnected = false;
    authEmulatorConnected = false;
    firestoreEmulatorConnected = false;
    constructor(options) {
        this.options = options;
    }
    get functions() {
        const functionsInstance = (0, functions_1.getFunctions)(this.options.app, this.options.region);
        if (!this.functionsEmulatorConnected && this.options.useFunctionsEmulatorPort !== null) {
            (0, functions_1.connectFunctionsEmulator)(functionsInstance, '127.0.0.1', this.options.useFunctionsEmulatorPort);
            this.functionsEmulatorConnected = true;
        }
        return new FirebaseFunctionsCaller_1.FirebaseFunctionsCaller(this.options, functionsInstance);
    }
    get auth() {
        const authInstance = (0, auth_1.getAuth)(this.options.app);
        if (!this.authEmulatorConnected && this.options.useAuthEmulatorPort !== null) {
            (0, auth_1.connectAuthEmulator)(authInstance, `http://127.0.0.1:${this.options.useAuthEmulatorPort}`);
            this.authEmulatorConnected = true;
        }
        return new FirebaseAuthenticator_1.FirebaseAuthenticator(this.options, authInstance);
    }
    get firestore() {
        const firestoreInstance = (0, firestore_2.getFirestore)(this.options.app);
        if (!this.firestoreEmulatorConnected && this.options.useFirestoreEmulatorPort !== null) {
            (0, firestore_2.connectFirestoreEmulator)(firestoreInstance, '127.0.0.1', this.options.useFirestoreEmulatorPort);
            this.firestoreEmulatorConnected = true;
        }
        return new FirebaseFirestore_1.FirebaseFirestoreDocument(this.options, new firestore_1.FirestorePath(), firestoreInstance);
    }
}
exports.FirebaseApp = FirebaseApp;
