"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const src_1 = require("../../../src");
const testSrc_1 = require("../../../src/testSrc");
describe('ParameterBuilder', () => {
    const logger = new src_1.VoidLogger();
    it('undefined', () => {
        const builder = new src_1.ParameterBuilder('undefined', () => 'asdf');
        (0, testSrc_1.expect)(builder.expectedTypes).to.be.deep.equal(new Set(['undefined']));
        (0, testSrc_1.expect)(builder.build(undefined, logger.nextIndent)).to.be.equal('asdf');
    });
    it('boolean', () => {
        const builder = new src_1.ParameterBuilder('boolean', value => value ? 'a' : 'b');
        (0, testSrc_1.expect)(builder.expectedTypes).to.be.deep.equal(new Set(['boolean']));
        (0, testSrc_1.expect)(builder.build(true, logger.nextIndent)).to.be.equal('a');
        (0, testSrc_1.expect)(builder.build(false, logger.nextIndent)).to.be.equal('b');
    });
    it('string', () => {
        const builder = new src_1.ParameterBuilder('string', value => `${value}asdf`);
        (0, testSrc_1.expect)(builder.expectedTypes).to.be.deep.equal(new Set(['string']));
        (0, testSrc_1.expect)(builder.build('', logger.nextIndent)).to.be.equal('asdf');
        (0, testSrc_1.expect)(builder.build('ölkj', logger.nextIndent)).to.be.equal('ölkjasdf');
    });
    it('number', () => {
        const builder = new src_1.ParameterBuilder('number', value => value.toString());
        (0, testSrc_1.expect)(builder.expectedTypes).to.be.deep.equal(new Set(['number']));
        (0, testSrc_1.expect)(builder.build(0, logger.nextIndent)).to.be.equal('0');
        (0, testSrc_1.expect)(builder.build(-1.5, logger.nextIndent)).to.be.equal('-1.5');
    });
    it('bigint', () => {
        const builder = new src_1.ParameterBuilder('bigint', value => value.toString());
        (0, testSrc_1.expect)(builder.expectedTypes).to.be.deep.equal(new Set(['bigint']));
        (0, testSrc_1.expect)(builder.build(0n, logger.nextIndent)).to.be.equal('0');
        (0, testSrc_1.expect)(builder.build(-15n, logger.nextIndent)).to.be.equal('-15');
    });
    it('object', () => {
        const builder = new src_1.ParameterBuilder('object', value => value === null ? null : 'asdf');
        (0, testSrc_1.expect)(builder.expectedTypes).to.be.deep.equal(new Set(['object']));
        (0, testSrc_1.expect)(builder.build(null, logger.nextIndent)).to.be.equal(null);
        (0, testSrc_1.expect)(builder.build({}, logger.nextIndent)).to.be.equal('asdf');
    });
});
